@@ -1,5 +1,5 @@
 package Net::UPS;
-$Net::UPS::VERSION = '0.15';
+$Net::UPS::VERSION = '0.16';
 {
   $Net::UPS::DIST = 'Net-UPS';
 }
@@ -505,7 +505,7 @@ sub post {
     if ( $response->is_error ) {
         die $response->status_line();
     }
-    return $response->content;
+    return $response->decoded_content;
 }
 
 
